#!/usr/bin/env python
# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Command line interface set up."""

__metaclass__ = type
__all__ = [
    'main',
    ]

import sys
from lpsetup import (
    __doc__ as description,
    argparser,
    exceptions,
    )
from lpsetup.subcommands import (
    finish_inithost,
    inithost,
    initlxc,
    initrepo,
    install_lxc,
    update,
    version,
    )


subcommands = [
    ('finish-init-host', finish_inithost.SubCommand),
    ('init-host', inithost.SubCommand),
    ('init-lxc', initlxc.SubCommand),
    ('init-repo', initrepo.SubCommand),
    ('install-lxc', install_lxc.SubCommand),
    ('update', update.SubCommand),
    ('version', version.SubCommand),
    ]


def main(args=None):
    if args is None:
        args = sys.argv[1:]
    parser = argparser.ArgumentParser(description=description)
    for name, klass in subcommands:
        parser.register_subcommand(name, klass)
    try:
        args = parser.parse_args(args)
    except SystemExit as err:
        return err.code
    try:
        return args.main(args)
    except (exceptions.ExecutionError, KeyboardInterrupt) as err:
        return err
