#!/usr/bin/env python
# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Global settings and defaults for lpsetup."""

APT_REPOSITORIES = (
    'deb http://archive.ubuntu.com/ubuntu {distro} multiverse',
    'deb http://archive.ubuntu.com/ubuntu {distro}-updates multiverse',
    'deb http://archive.ubuntu.com/ubuntu {distro}-security multiverse',
    'ppa:launchpad/ppa',
    'ppa:bzr/ppa',
    )
# a2enmod requires apache2.2-common
BASE_PACKAGES = ['ssh', 'bzr', 'apache2.2-common']
PY26_PACKAGES = ['python-argparse', 'python-shelltoolbox']
CHECKOUT_DIR = '~/launchpad/lp-branches'
DEPENDENCIES_DIR = '~/launchpad/lp-sourcedeps'
HOSTS_CONTENT = (
    ('127.0.0.88',
        'launchpad.dev answers.launchpad.dev archive.launchpad.dev '
        'api.launchpad.dev bazaar-internal.launchpad.dev beta.launchpad.dev '
        'blueprints.launchpad.dev bugs.launchpad.dev code.launchpad.dev '
        'feeds.launchpad.dev id.launchpad.dev keyserver.launchpad.dev '
        'lists.launchpad.dev openid.launchpad.dev '
        'ubuntu-openid.launchpad.dev ppa.launchpad.dev '
        'private-ppa.launchpad.dev testopenid.dev translations.launchpad.dev '
        'xmlrpc-private.launchpad.dev xmlrpc.launchpad.dev'),
    ('127.0.0.99', 'bazaar.launchpad.dev'),
    )
HOSTS_FILE = '/etc/hosts'
LP_APACHE_MODULES = 'proxy proxy_http rewrite ssl deflate headers'
LP_APACHE_ROOTS = (
    '/var/tmp/bazaar.launchpad.dev/static',
    '/var/tmp/bazaar.launchpad.dev/mirrors',
    '/var/tmp/archive',
    '/var/tmp/ppa',
    )
LP_BZR_LOCATIONS = {
    '{repository}': {
        'submit_branch': '{branch_dir}',
        'public_branch': 'bzr+ssh://bazaar.launchpad.net/~{lpuser}/launchpad',
        'public_branch:policy': 'appendpath',
        'push_location': 'lp:~{lpuser}/launchpad',
        'push_location:policy': 'appendpath',
        'merge_target': '{branch_dir}',
        'submit_to': 'merge@code.launchpad.net',
        },
    '{branch_dir}': {
        'public_branch':
            'bzr+ssh://bazaar.launchpad.net/~launchpad-pqm/launchpad/devel',
        }
    }
LP_BRANCH_NAME = 'devel'
LP_CHECKOUT_NAME = 'sandbox'
LP_REPOSITORY_DIR = '~/launchpad/lp-branches'
LP_PACKAGES = [
    # "launchpad-database-dependencies-9.1" can be removed once 8.x is
    # no longer an option in "launchpad-developer-dependencies.
    'launchpad-database-dependencies-9.1',
    'launchpad-developer-dependencies', 'apache2',
    'apache2-mpm-worker', 'libapache2-mod-wsgi',
    ]
LP_HTTP_REPO = 'http://bazaar.launchpad.net/~launchpad-pqm/launchpad/devel'
LP_SSH_REPO = 'lp:launchpad'
LP_SOURCE_DEPS = (
    'http://bazaar.launchpad.net/~launchpad/lp-source-dependencies/trunk')
LPSETUP_PPA = 'ppa:yellow/ppa'
LXC_CONFIG_TEMPLATE = '/etc/lxc/lp-setup.conf'
LXC_GUEST_ARCH = 'i386'
LXC_GUEST_CHOICES = ('lucid', 'oneiric', 'precise')
LXC_GUEST_OS = LXC_GUEST_CHOICES[0]
LXC_IP_COMMAND = ('/usr/bin/env', 'lp-lxc-ip', '-i', 'eth0', '-n')
LXC_LP_DIR_PATTERN = '/tmp/lxc-lp-*'
LXC_LP_TEST_DIR_PATTERN = '/var/lib/lxc/{lxc_name}-tmp-*'
LXC_NAME = 'lptests'
LXC_OPTIONS = """
lxc.network.type = veth
lxc.network.link = {interface}
lxc.network.flags = up
"""
LXC_PACKAGES = ('lxc', 'libvirt-bin')
LXC_PATH = '/var/lib/lxc/'
SCRIPTS = ('lp-setup-lxc-build', 'lp-setup-lxc-cleanup', 'lp-setup-lxc-test')
SSH_KEY_NAME = 'id_rsa'
