#!/usr/bin/env python
# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Example objects used in tests."""

__metaclass__ = type
__all__ = [
    'step1',
    'step2',
    'StepsBasedSubCommand',
    'StepsBasedSubCommandWithErrors',
    'bad_step',
    'SubCommand',
    ]

import subprocess

from lpsetup import argparser


def step1(foo):
    print 'step1 received ' + foo


def step2(foo, bar):
    print 'step2 received {0} and {1}'.format(foo, bar)
step2.step_name = 'mystep'


def bad_step(foo):
    raise subprocess.CalledProcessError(1, 'command')


class SubCommand(argparser.BaseSubCommand):
    """An example sub command."""

    help = 'Sub command example.'

    def add_arguments(self, parser):
        super(SubCommand, self).add_arguments(parser)
        parser.add_argument('--foo')

    def run(self, namespace):
        return namespace


class StepsBasedSubCommand(argparser.StepsBasedSubCommand):
    """An example steps based sub command."""

    steps = (
        (step1, 'foo'),
        (step2, 'foo', 'bar'),
        )

    def add_arguments(self, parser):
        super(StepsBasedSubCommand, self).add_arguments(parser)
        parser.add_argument('--foo')
        parser.add_argument('--bar')


class StepsBasedSubCommandWithErrors(StepsBasedSubCommand):
    """An example steps based sub command (containing a failing step)."""

    steps = (
        (step1, 'foo'),
        (bad_step, 'foo'),
        (step2, 'foo', 'bar'),
        )


class DynamicStepsBasedSubCommand(StepsBasedSubCommand):
    """An example steps based sub command (using internal step dispatcher)."""

    def call_step1(self, namespace, step, args):
        print 'running step1 with {args} while bar is {bar}'.format(
            args=','.join(args), bar=namespace.bar)
        step(*args)
