#!/usr/bin/env python
# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Tests for the finish-init-host sub command."""

import unittest

from lpsetup import handlers
from lpsetup.subcommands import finish_inithost
from lpsetup.tests.utils import (
    get_random_string,
    StepsBasedSubCommandTestMixin,
    )


setup_launchpad_step = (
    finish_inithost.setup_launchpad, ['user', 'code_dir'])


def get_arguments():
    repo = '~/' + get_random_string()
    checkout = get_random_string()
    user = get_random_string()
    return ('-r', repo, '--checkout-name', checkout, '-u', user)


class FinishInitHostTest(StepsBasedSubCommandTestMixin, unittest.TestCase):

    sub_command_class = finish_inithost.SubCommand
    expected_arguments = get_arguments()
    expected_handlers = (
        handlers.handle_user,
        handlers.handle_directories,
        handlers.handle_code_dir,
        )

    @property
    def expected_steps(self):
        return (
            setup_launchpad_step,
            )
    needs_root = True
