#!/usr/bin/env python
# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Tests for the initlxc sub command."""

import random
import unittest

from lpsetup import (
    handlers,
    settings,
    )
from lpsetup.subcommands import initlxc
from lpsetup.tests.subcommands import test_inithost
from lpsetup.tests.utils import (
    get_random_string,
    StepsBasedSubCommandTestMixin,
    )

initialize_step = (initlxc.initialize, ['user'])
create_lxc_step = (
    initlxc.create_lxc, ['lxc_name', 'lxc_arch', 'lxc_os', 'user'])
start_lxc_step = (initlxc.start_lxc, ['lxc_name'])
wait_for_lxc_step = (initlxc.wait_for_lxc, ['lxc_name', 'ssh_key_path'])
install_lpsetup_in_lxc_step = (
    initlxc.install_lpsetup_in_lxc, ['lxc_name', 'ssh_key_path', 'lxc_os',
                                     'user', 'home_dir', 'lpsetup_branch'])
inithost_in_lxc_step = (
    initlxc.inithost_in_lxc,
    ['lxc_name', 'ssh_key_path', 'user', 'email', 'full_name', 'lpuser',
     'private_key', 'public_key', 'ssh_key_name',  'home_dir'])
stop_lxc_step = (initlxc.stop_lxc, ['lxc_name', 'ssh_key_path'])


def get_arguments():
    inithost_arguments = test_inithost.get_arguments()
    lxc_name = get_random_string()
    lxc_arch = random.choice(['i386', 'amd64'])
    lxc_os = random.choice(settings.LXC_GUEST_CHOICES)
    return (
        lxc_name, '-A', lxc_arch, '-R', lxc_os,
        '--stop-lxc') + inithost_arguments


class InitLxcTest(StepsBasedSubCommandTestMixin, unittest.TestCase):

    sub_command_class = initlxc.SubCommand
    expected_arguments = get_arguments()
    expected_handlers = (
        handlers.handle_user,
        handlers.handle_lpuser_as_username,
        handlers.handle_userdata,
        handlers.handle_ssh_keys,
        )
    expected_steps = (
        initialize_step,
        create_lxc_step,
        start_lxc_step,
        wait_for_lxc_step,
        install_lpsetup_in_lxc_step,
        inithost_in_lxc_step,
        stop_lxc_step,
        )
    needs_root = True
