#!/usr/bin/env python
# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Tests for the install-lxc sub command."""

import unittest

from lpsetup import handlers
from lpsetup.subcommands import install_lxc
from lpsetup.tests.subcommands import (
    test_initlxc,
    )
from lpsetup.tests.utils import (
    get_random_string,
    StepsBasedSubCommandTestMixin,
    )


create_scripts_step = (
    install_lxc.create_scripts, ['lxc_name', 'ssh_key_path', 'user'])

init_repo_in_lxc_step = (
    install_lxc.init_repo_in_lxc, [
        'lxc_name', 'ssh_key_path', 'home_dir', 'user', 'source', 'use_http',
        'branch_name', 'checkout_name', 'repository',
        ])

update_in_lxc_step = (
    install_lxc.update_in_lxc, [
        'lxc_name', 'ssh_key_path', 'home_dir', 'user', 'external_path',
        'use_http', 'checkout_name', 'repository',
        ])

finish_inithost_in_lxc_step = (
    install_lxc.finish_inithost_in_lxc, [
        'lxc_name', 'ssh_key_path', 'home_dir', 'user', 'repository',
        'checkout_name',
        ])


def get_arguments():
    repository = '~/' + get_random_string()
    return test_initlxc.get_arguments() + (
        '-r', repository,
        '--create-scripts',
        )


class InstallLxcTest(StepsBasedSubCommandTestMixin, unittest.TestCase):

    sub_command_class = install_lxc.SubCommand
    expected_arguments = get_arguments()
    expected_handlers = test_initlxc.InitLxcTest.expected_handlers + (
        handlers.handle_directories,
        handlers.handle_code_dir,
        handlers.handle_source,
        )
    expected_steps = test_initlxc.InitLxcTest.expected_steps + (
        create_scripts_step,
        init_repo_in_lxc_step,
        update_in_lxc_step,
        finish_inithost_in_lxc_step,
        )
    needs_root = True
    maxDiff = None
